pub struct InitializeImmutableOwnerBumps {}Available on crate feature
token_2022 only.Trait Implementations
Sourceimpl<'info> Accounts<'info, InitializeImmutableOwnerBumps> for InitializeImmutableOwner<'info>where
'info: 'info,
impl<'info> Accounts<'info, InitializeImmutableOwnerBumps> for InitializeImmutableOwner<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut InitializeImmutableOwnerBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut InitializeImmutableOwnerBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreAuto Trait Implementations
impl Freeze for InitializeImmutableOwnerBumps
impl RefUnwindSafe for InitializeImmutableOwnerBumps
impl Send for InitializeImmutableOwnerBumps
impl Sync for InitializeImmutableOwnerBumps
impl Unpin for InitializeImmutableOwnerBumps
impl UnsafeUnpin for InitializeImmutableOwnerBumps
impl UnwindSafe for InitializeImmutableOwnerBumps